// C Source File
// Created 27/07/2003; 12:01:42

#include "mkcomplib.h"

/*===============================================================================================
== Komp compression of a variable in a temporary handle
=================================================================================================
== hsym_var_src : HSym structure of the var to compress
== error : pointer to return the error code
=================================================================================================
== return a handle with the compressed datas : the H_NULL handle if there is a error.
===============================================================================================*/
HANDLE komp_hsym_temp(HSym hsym_var_src, CompErr * error) {
  HANDLE h_var;
  unsigned char * data;
  unsigned short length;
  short type;

  unsigned short * stat=NULL;
  TREE * tree=NULL;
  unsigned short comp_len;
  short offset;
  short nb1;
  short nb2;
  short mode;

  HANDLE h;
  unsigned char * dest;
  
  if (hsym_var_src.folder==H_NULL) {
    *error=COMP_ERR_NO_SRC_VAR;
    return H_NULL;
  }
  
  h_var=DerefSym(hsym_var_src)->handle;
  data=HLock(h_var);
  if (data==NULL) {
    *error=COMP_ERR_MEM;
    return H_NULL;
  }
  length=*(unsigned short *)data;

  type=data[length+1];

  *error=study_komp(data+2,length,&stat,&tree,&comp_len,&offset,&nb1,&nb2,&mode,TRUE);
  if (*error!=COMP_NO_ERR) {
    HeapUnlock(h_var);
    return H_NULL;
  }

  h=HeapAlloc(comp_len+2);
  if (h==H_NULL) {
    free(tree);
    free(stat);
    *error=COMP_ERR_MEM;
    return H_NULL;
  }
  
  dest=HLock(h);

  *error=mk_komp(data+2,length,dest,stat,tree,comp_len,offset,nb1,nb2,mode,type,TRUE);
  
  if (*error!=COMP_NO_ERR) {
    HeapFree(h);
    return H_NULL;
  }
  
  HeapUnlock(h_var);
  return h;
}

